summaryrefslogtreecommitdiffstats
path: root/loader2
diff options
context:
space:
mode:
authorDavid Cantrell <dcantrell@redhat.com>2008-08-13 11:19:00 -1000
committerDavid Cantrell <dcantrell@redhat.com>2008-08-13 11:19:00 -1000
commit00e1bbedde5dc08abc31cfafb8834d670599d1e3 (patch)
tree71121a2e62add0dcb834ed81adda825be3a333de /loader2
parent09315bb6d6e5db4d5d21d116d910dda8943be63d (diff)
downloadanaconda-00e1bbedde5dc08abc31cfafb8834d670599d1e3.tar.gz
anaconda-00e1bbedde5dc08abc31cfafb8834d670599d1e3.tar.xz
anaconda-00e1bbedde5dc08abc31cfafb8834d670599d1e3.zip
Rest of stage2.img changes.
Reference install.img in anaconda rather than stage2.img.
Diffstat (limited to 'loader2')
-rw-r--r--loader2/cdinstall.c8
-rw-r--r--loader2/hdinstall.c2
-rw-r--r--loader2/loader.c2
-rw-r--r--loader2/nfsinstall.c2
-rw-r--r--loader2/urlinstall.c8
5 files changed, 11 insertions, 11 deletions
diff --git a/loader2/cdinstall.c b/loader2/cdinstall.c
index e3dd4ab71..3b676c1f5 100644
--- a/loader2/cdinstall.c
+++ b/loader2/cdinstall.c
@@ -256,7 +256,7 @@ static void queryCDMediaCheck(char *dev, char *location) {
continue;
}
- if (asprintf(&stage2loc, "%s/images/stage2.img",
+ if (asprintf(&stage2loc, "%s/images/install.img",
location) == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
abort();
@@ -299,7 +299,7 @@ static char *setupCdrom(char *location, struct loaderData_s *loaderData,
return NULL;
}
- if (asprintf(&stage2loc, "%s/images/stage2.img", location) == -1) {
+ if (asprintf(&stage2loc, "%s/images/install.img", location) == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
abort();
}
@@ -367,8 +367,8 @@ static char *setupCdrom(char *location, struct loaderData_s *loaderData,
/* aid system recovery. */
if (FL_RESCUE(flags) && !FL_TEXT(flags) &&
totalMemory() > 128000) {
- rc = copyFile(stage2loc, "/tmp/stage2.img");
- stage2img = strdup("/tmp/stage2.img");
+ rc = copyFile(stage2loc, "/tmp/install.img");
+ stage2img = strdup("/tmp/install.img");
stage2inram = 1;
} else {
stage2img = strdup(stage2loc);
diff --git a/loader2/hdinstall.c b/loader2/hdinstall.c
index 662465150..eaf3da98f 100644
--- a/loader2/hdinstall.c
+++ b/loader2/hdinstall.c
@@ -328,7 +328,7 @@ char * mountHardDrive(struct installMethod * method,
*/
substr = strstr(dir, ".img");
if (!substr || (substr && *(substr+4) != '\0')) {
- if (asprintf(&dir, "%s/stage2.img", dir) == -1) {
+ if (asprintf(&dir, "%s/install.img", dir) == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
abort();
}
diff --git a/loader2/loader.c b/loader2/loader.c
index c2f2c3cb2..7ed1042cc 100644
--- a/loader2/loader.c
+++ b/loader2/loader.c
@@ -1176,7 +1176,7 @@ static char *doLoaderMain(struct loaderData_s *loaderData,
*/
char *tmp;
- if (asprintf(&tmp, "%s/images/stage2.img",
+ if (asprintf(&tmp, "%s/images/install.img",
loaderData->instRepo) == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
abort();
diff --git a/loader2/nfsinstall.c b/loader2/nfsinstall.c
index 8bc9dd297..efde32a1c 100644
--- a/loader2/nfsinstall.c
+++ b/loader2/nfsinstall.c
@@ -155,7 +155,7 @@ char * mountNfsImage(struct installMethod * method,
*/
substr = strstr(directory, ".img");
if (!substr || (substr && *(substr+4) != '\0')) {
- if (asprintf(&tmp, "nfs:%s:%s/images/stage2.img",
+ if (asprintf(&tmp, "nfs:%s:%s/images/install.img",
host, directory) == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
abort();
diff --git a/loader2/urlinstall.c b/loader2/urlinstall.c
index 4cbb866f6..48d1cb73d 100644
--- a/loader2/urlinstall.c
+++ b/loader2/urlinstall.c
@@ -118,7 +118,7 @@ static int loadUrlImages(struct iurlinfo * ui) {
if ((path = strndup(ui->prefix, slash - ui->prefix)) == NULL)
path = ui->prefix;
/* grab the updates.img before stage2.img so that we minimize our
* ramdisk usage */
if (asprintf(&buf, "%s/%s", path, "updates.img") == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
@@ -140,7 +140,7 @@ static int loadUrlImages(struct iurlinfo * ui) {
free(buf);
/* grab the product.img before stage2.img so that we minimize our
* ramdisk usage */
if (asprintf(&buf, "%s/%s", path, "product.img") == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
@@ -159,7 +159,7 @@ static int loadUrlImages(struct iurlinfo * ui) {
free(buf);
- if (asprintf(&dest, "/tmp/stage2.img") == -1) {
+ if (asprintf(&dest, "/tmp/install.img") == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__, __LINE__);
abort();
}
@@ -224,7 +224,7 @@ char *mountUrlImage(struct installMethod *method, char *location,
*/
substr = strstr(ui.prefix, ".img");
if (!substr || (substr && *(substr+4) != '\0')) {
- if (asprintf(&ui.prefix, "%s/images/stage2.img",
+ if (asprintf(&ui.prefix, "%s/images/install.img",
ui.prefix) == -1) {
logMessage(CRITICAL, "%s: %d: %m", __func__,
__LINE__);
@@ -118,7 +118,7 @@ static int loadUrlImages(struct iurlinfo * ui) {
if ((path = strndup(ui->prefix, slash - ui->prefix)) == NULL)
path = ui->prefix;
- /* grab the updates.img before stage2.img so that we minimize our
+ /* grab the updates.img before install.img so that we minimize our
* ramdisk usage */
if (asprintf(&buf, "%s/%s", path, "updates.img") == -1) {
@@ -140,7 +140,7 @@ static int loadUrlImages(struct iurlinfo * ui) {
free(buf);
- /* grab the product.img before stage2.img so that we minimize our
+ /* grab the product.img before install.img so that we minimize our
* ramdisk usage */
if (asprintf(&buf, "%s/%s", path, "product.img") == -1) {